==> modx-2.2.1-pl-ja.zip: modx-2.2.1-pl-ja/core/lexicon/ja/file.inc.php <==
<?php
/**
 * File Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author Nick http://smallworld.west-tokyo.com
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 * @author honda http://kogus.org
 */
$_lang['directory'] = 'ディレクトリ';
$_lang['file_confirm_remove'] = 'このファイルを本当に削除しますか？';
$_lang['file_create'] = 'ファイルを作成';
$_lang['file_deleted'] = '成功';
$_lang['file_delete_file'] = 'ファイルの削除';
$_lang['file_delete_folder'] = 'フォルダの削除';
$_lang['file_download'] = 'Download File';
$_lang['file_download_file'] = 'ファイルのダウンロード';
$_lang['file_download_unzip'] = 'ファイルの解凍';
$_lang['file_edit'] = '編集';
$_lang['file_err_chmod'] = 'chmod実行中に予期せぬエラーが起こりました';
$_lang['file_err_chmod_ns'] = 'chmod設定を行ってください。';
$_lang['file_err_ext_not_allowed'] = '拡張子`[[+ext]]`のファイルは許可されていません。';
$_lang['file_err_filter'] = '絞り込み条件ではファイルが見つりませんでした。';
$_lang['file_err_invalid'] = 'このファイルは通常のファイルではないため削除できませんでした。';
$_lang['file_err_nf'] = 'ファイルが存在しません';
$_lang['file_err_ns'] = '正しいファイルを選択してください。';
$_lang['file_err_open'] = 'ファイルが開けません。: ';
$_lang['file_err_perms_rename'] = 'ファイルの名称変更に必要なパーミッションがウェブサーバーにありません。';
$_lang['file_err_perms_remove'] = 'ファイルの削除に必要なパーミッションがウェブサーバーにありません。';
$_lang['file_err_rename'] = 'ファイル名を変更できませんでいた。パーミッションが正しく設定されているかどうか確認してください。';
$_lang['file_err_remove'] = 'ファイルを削除できませんでした。パーミッションが正しく設定されているかどうか確認してください。';
$_lang['file_err_save'] = 'ファイルを保存できません。保存先のディレクトリが書き込み可能かどうか確認してください。';
$_lang['file_err_too_large'] = 'ファイルサイズが [[+size]] byte あり、大きすぎます。アップロードするファイルは [[+allowed]] byte 以下である必要があります。';
$_lang['file_err_unzip'] = 'ファイルの解凍が失敗しました';
$_lang['file_err_unzip_invalid_path'] = '解凍済みファイルのパスが不適切です。';
$_lang['file_err_unzip_missing_lib'] = ' zipライブラリが見当たりません。 (php_zip.dll / zip.so)';
$_lang['file_err_upload'] = 'ファイルのアップロード中にエラーが発生しました。';
$_lang['file_exists_hk'] = '<b>{0}</b>ファイルは既に存在します。';
$_lang['file_extensions'] = 'ファイル拡張子';
$_lang['file_folder_enter_new'] = '新しいフォルダ名を入力';
$_lang['file_folder_chmod'] = 'パーミッションを変更';
$_lang['file_folder_create'] = 'ディレクトリを作成';
$_lang['file_folder_create_here'] = 'ここにディレクトリを作成';
$_lang['file_folder_created'] = 'フォルダを作成しました';
$_lang['file_folder_deleted'] = 'フォルダを削除しました';
$_lang['file_folder_err_ae'] = '同名のディレクトリがその場所に存在します。';
$_lang['file_folder_err_chmod'] = 'パーミッションを変更できませんでした。MODX外部から変更する必要があります。';
$_lang['file_folder_err_create'] = 'ディレクトリ作成中に不明なエラーが起こりました。';
$_lang['file_folder_err_invalid'] = '指定されたディレクトリはディレクトリではありません。';
$_lang['file_folder_err_invalid_path'] = 'パス名が不正です。';
$_lang['file_folder_err_nf'] = 'フォルダーが存在しません。';
$_lang['file_folder_err_ns'] = '正しいディレクトリ名を指定してください。';
$_lang['file_folder_err_ns_name'] = '正しいフォルダ名を指定してください。';
$_lang['file_folder_err_parent_invalid'] = '不正なディレクトリを指定しています。';
$_lang['file_folder_err_perms'] = 'ディレクトリの更新に必要なパーミッションがウェブサーバーにありません。';
$_lang['file_folder_err_perms_parent'] = 'ディレクトリの追加に必要なパーミッションがウェブサーバーにありません。';
$_lang['file_folder_err_perms_remove'] = 'ディレクトリの削除に必要なパーミッションがウェブサーバーにありません。';
$_lang['file_folder_err_perms_upload'] = 'ディレクトリのアップロードに必要なパーミッションがウェブサーバーにありません。';
$_lang['file_folder_err_rename'] = 'ディレクトリ名を変更中に不明なエラーが発生しました。';
$_lang['file_folder_err_remove'] = 'ディレクトリの削除中にエラーが発生しました。';
$_lang['file_folder_parent'] = '親ディレクトリ';
$_lang['file_folder_remove'] = 'ディレクトリの削除';
$_lang['file_folder_remove_confirm'] = '本当にこのディレクトリを削除しますか？　ウェブサイトの構成が壊れる可能性があります。';
$_lang['file_last_accessed'] = '最終アクセス';
$_lang['file_last_modified'] = '最終更新';
$_lang['file_name'] = 'ファイル名';
$_lang['file_remove'] = 'ファイルを削除';
$_lang['file_remove_confirm'] = 'このファイルを完全に削除しますか？';
$_lang['file_saved'] = 'ファイルが正常に保存されました';
$_lang['file_size'] = 'ファイル容量';
$_lang['file_unzip'] = '解凍に成功しました';
$_lang['file_upload'] = 'ファイルアップロード';
$_lang['file_upload_here'] = 'ここにファイルをアップロード';
$_lang['file_view'] = 'ファイル閲覧';
$_lang['files_access_denied'] = 'アクセスが拒否されました';
$_lang['files_data'] = 'データ';
$_lang['files_directories'] = 'ディレクトリ';
$_lang['files_dirwritable'] = 'ディレクトリ書き込み可？';
$_lang['files_dir_listing'] = 'ディレクトリ一覧:';
$_lang['files_editfile'] = 'ファイルの編集';
$_lang['files_filename'] = 'ファイル名';
$_lang['files_fileoptions'] = 'オプション';
$_lang['files_files'] = 'ファイルマネージャー';
$_lang['files_filesize'] = 'ファイルサイズ';
$_lang['files_file_type'] = 'ファイルタイプ: ';
$_lang['files_modified'] = '更新日時';
$_lang['files_viewfile'] = 'ファイルの表示';
$_lang['upf_abort'] = '中止';
$_lang['upf_abort_desc'] = 'アップロードを停止します。';
$_lang['upf_aborted'] = 'ユーザー側の操作で中止されました。';
$_lang['upf_add'] = '追加';
$_lang['upf_add_desc'] = 'アップロードキューにファイルを追加します。';
$_lang['upf_close'] = '閉じる';
$_lang['upf_close_desc'] = 'ウィンドウを閉じます。';
$_lang['upf_err_failed'] = 'サーバーは利用できないか、内部エラーが発生しています。';
$_lang['upf_err_filetype'] = '選択されたファイルの拡張子は許可されていません。<br/>次に示す許可された拡張子のファイルを選択して下さい： {1}';
$_lang['upf_error'] = 'エラー';
$_lang['upf_filename'] = 'ファイル名';
$_lang['upf_note'] = 'ノート';
$_lang['upf_progress_wait'] = '待機中です';
$_lang['upf_queued'] = 'アップロードキューを作成しました。';
$_lang['upf_remove'] = '削除';
$_lang['upf_remove_desc'] = 'アップロードキューから削除します。';
$_lang['upf_reset'] = 'リセット';
$_lang['upf_reset_desc'] = 'キューをリセットします。';
$_lang['upf_state'] = '状態';
$_lang['upf_success'] = 'OK.';
$_lang['upf_upload'] = 'アップロード';
$_lang['upf_upload_desc'] = 'アップロードキューのファイルをサーバーへ送信します。';
$_lang['upf_upload_err'] = 'アップロードエラー';
$_lang['upf_uploading'] = 'アップロード中です';
$_lang['upf_uploading_desc'] = 'アップロード中: {1} ファイル中 {0} ファイル完了。';
$_lang['upload_files'] = 'ここにファイルをアップロード';

==> modx-2.3.3-pl-ja.zip: modx-2.3.3-pl-ja/core/lexicon/ja/file.inc.php <==
<?php
/**
 * File English lexicon topic
 *
 * @language en
 * @package modx
 * @subpackage lexicon
 */
$_lang['directory'] = 'ディレクトリ';
$_lang['file_confirm_remove'] = 'このファイルを本当に削除しますか？';
$_lang['file_create'] = 'ファイルを作成';
$_lang['file_deleted'] = '成功';
$_lang['file_delete_file'] = 'ファイルを削除';
$_lang['file_delete_folder'] = 'フォルダを削除';
$_lang['file_download'] = 'ファイルをダウンロード';
$_lang['file_download_file'] = 'ファイルのダウンロード';
$_lang['file_download_unzip'] = 'ファイルの解凍';
$_lang['file_edit'] = '編集';
$_lang['file_err_ae'] = 'File %s already exists';
$_lang['file_err_chmod'] = 'chmod実行中に予期せぬエラーが起こりました。';
$_lang['file_err_chmod_ns'] = 'chmod設定を行ってください。';
$_lang['file_err_create'] = 'An unknown error occurred while trying to create the file.';
$_lang['file_err_ext_not_allowed'] = '拡張子が`[[+ext]]`のファイルをアップロードする許可がありません。';
$_lang['file_err_filter'] = '絞り込み条件ではファイルが見つりませんでした。';
$_lang['file_err_invalid'] = 'このファイルは通常のファイルではないため削除できませんでした。';
$_lang['file_err_nf'] = 'ファイルが存在しません。';
$_lang['file_err_ns'] = '正しいファイルを選択してください。';
$_lang['file_err_open'] = 'ファイルが開けません。: ';
$_lang['file_err_perms_rename'] = 'ファイルの名称変更に必要なパーミッションがウェブサーバーにありません。';
$_lang['file_err_perms_remove'] = 'ファイルの削除に必要なパーミッションがウェブサーバーにありません。';
$_lang['file_err_rename'] = 'ファイル名を変更できませんでいた。パーミッションが正しく設定されているかどうか確認してください。';
$_lang['file_err_remove'] = 'ファイルを削除できませんでした。パーミッションが正しく設定されているかどうか確認してください。';
$_lang['file_err_save'] = 'ファイルを保存できません。保存先のディレクトリが書き込み可能かどうか確認してください。';
$_lang['file_err_too_large'] = 'アップロードされたファイル（[[+size]]バイト）はサイズが大きすぎるため保存できませんでした。[[+allowed]]バイトを超えないようにしてください。';
$_lang['file_err_unzip'] = 'ファイルの解凍が失敗しました。';
$_lang['file_err_unzip_invalid_path'] = '解凍済みファイルのパスが不適切です。';
$_lang['file_err_unzip_missing_lib'] = ' zipライブラリが見当たりません。（php_zip.dll / zip.so）';
$_lang['file_err_upload'] = 'ファイルのアップロード中にエラーが発生しました。';
$_lang['file_exists_hk'] = '<b>{0}</b>ファイルは既に存在します。';
$_lang['file_extensions'] = 'ファイル拡張子';
$_lang['file_folder_enter_new'] = '新しいフォルダ名を入力';
$_lang['file_folder_chmod'] = 'パーミッションを変更';
$_lang['file_folder_create'] = 'ディレクトリを作成';
$_lang['file_folder_create_here'] = 'ここにディレクトリを作成';
$_lang['file_folder_created'] = 'フォルダを作成しました。';
$_lang['file_folder_deleted'] = 'フォルダを削除しました。';
$_lang['file_folder_err_ae'] = '同名のディレクトリがその場所に存在します。';
$_lang['file_folder_err_chmod'] = 'パーミッションを変更できませんでした。MODX外部から変更する必要があります。';
$_lang['file_folder_err_create'] = 'ディレクトリ作成中に不明なエラーが起こりました。';
$_lang['file_folder_err_invalid'] = '指定されたディレクトリはディレクトリではありません。';
$_lang['file_folder_err_invalid_path'] = 'パス名が不正です。';
$_lang['file_folder_err_nf'] = 'フォルダーが存在しません。';
$_lang['file_folder_err_ns'] = '正しいディレクトリ名を指定してください。';
$_lang['file_folder_err_ns_name'] = '正しいフォルダ名を指定してください。';
$_lang['file_folder_err_parent_invalid'] = '不正なディレクトリを指定しています。';
$_lang['file_folder_err_perms'] = 'ディレクトリの更新に必要なパーミッションがウェブサーバーにありません。';
$_lang['file_folder_err_perms_parent'] = 'ディレクトリの追加に必要なパーミッションがウェブサーバーにありません。';
$_lang['file_folder_err_perms_remove'] = 'ディレクトリの削除に必要なパーミッションがウェブサーバーにありません。';
$_lang['file_folder_err_perms_upload'] = 'ディレクトリのアップロードに必要なパーミッションがウェブサーバーにありません。';
$_lang['file_folder_err_rename'] = 'ディレクトリ名を変更中に不明なエラーが発生しました。';
$_lang['file_folder_err_remove'] = 'ディレクトリの削除中にエラーが発生しました。';
$_lang['file_folder_parent'] = '親ディレクトリ';
$_lang['file_folder_remove'] = 'ディレクトリの削除';
$_lang['file_folder_remove_confirm'] = '本当にこのディレクトリを削除しますか？　ウェブサイトの構成が壊れる可能性があります。';
$_lang['file_last_accessed'] = '最終アクセス';
$_lang['file_last_modified'] = '最終更新';
$_lang['file_name'] = 'ファイル名';
$_lang['file_quick_create'] = 'ファイルをクイック作成';
$_lang['file_quick_update'] = 'クイック編集';
$_lang['file_remove'] = 'ファイルを削除';
$_lang['file_remove_confirm'] = 'このファイルを完全に削除しますか？';
$_lang['file_saved'] = 'ファイルが正常に保存されました。';
$_lang['file_size'] = 'ファイル容量';
$_lang['image_size'] = 'Image Size';
$_lang['file_unzip'] = '解凍に成功しました。';
$_lang['file_upload'] = 'ファイルアップロード';
$_lang['file_upload_here'] = 'ここにファイルをアップロード';
$_lang['file_view'] = 'ファイル閲覧';
$_lang['files_access_denied'] = 'アクセスが拒否されました。';
$_lang['files_data'] = 'データ';
$_lang['files_directories'] = 'ディレクトリ';
$_lang['files_dirwritable'] = 'ディレクトリ書き込み可？';
$_lang['files_dir_listing'] = 'ディレクトリ一覧:';
$_lang['files_editfile'] = 'ファイルの編集';
$_lang['files_filename'] = 'ファイル名';
$_lang['files_fileoptions'] = 'オプション';
$_lang['files_files'] = 'ファイルマネージャー';
$_lang['files_filesize'] = 'ファイルサイズ';
$_lang['files_file_type'] = 'ファイルタイプ: ';
$_lang['files_modified'] = '更新日時';
$_lang['files_viewfile'] = 'ファイルの表示';
$_lang['files_viewmode'] = 'プレビュー';
$_lang['files_viewmode_grid'] = 'Grid';
$_lang['files_viewmode_list'] = 'リスト';
$_lang['upf_abort'] = '中止';
$_lang['upf_abort_desc'] = 'アップロードを停止します。';
$_lang['upf_aborted'] = 'ユーザー側の操作で中止されました。';
$_lang['upf_add'] = '追加';
$_lang['upf_add_desc'] = 'アップロードキューにファイルを追加します。';
$_lang['upf_close'] = '閉じる';
$_lang['upf_close_desc'] = 'ウィンドウを閉じます。';
$_lang['upf_err_failed'] = 'サーバーは利用できないか、内部エラーが発生しています。';
$_lang['upf_err_filetype'] = '選択されたファイルの拡張子は許可されていません。<br/>次に示す許可された拡張子のファイルを選択してください： {1}';
$_lang['upf_error'] = 'エラー';
$_lang['upf_filename'] = 'ファイル名';
$_lang['upf_note'] = 'ノート';
$_lang['upf_progress_wait'] = '待機中...';
$_lang['upf_queued'] = 'キューを作成';
$_lang['upf_remove'] = '削除';
$_lang['upf_remove_desc'] = 'アップロードキューから削除します。';
$_lang['upf_reset'] = 'リセット';
$_lang['upf_reset_desc'] = 'キューをリセットします。';
$_lang['upf_state'] = '状態';
$_lang['upf_success'] = 'OK.';
$_lang['upf_upload'] = 'アップロード';
$_lang['upf_upload_desc'] = 'アップロードキューのファイルをサーバーへ送信します。';
$_lang['upf_upload_err'] = 'アップロードエラー';
$_lang['upf_uploading'] = 'アップロード中...';
$_lang['upf_uploading_desc'] = 'アップロード中: {1} ファイル中 {0} ファイル完了。';
$_lang['upload_files'] = 'ここにファイルをアップロード';
$_lang['no_file_err'] = 'No file was uploaded.';

$_lang['upload.buttons.choose']           = 'Choose file(s)';
$_lang['upload.buttons.clear']            = 'Empty list';
$_lang['upload.buttons.upload']           = 'アップロード';
$_lang['upload.buttons.close']            = '閉じる';
$_lang['upload.title.destination_path']   = 'Upload destination: [[+path]]';
$_lang['upload.upload_progress']          = '[[+loaded]] / [[+total]]';
$_lang['upload.notpermitted.extension']   = 'Upload of this filetype (.[[+ext]]) is not allowed!';
$_lang['upload.notpermitted.filesize']    = 'Filesize bigger ([[+size]]) than allowed! (max. [[+max]])';
$_lang['upload.columns.file']             = 'ファイル';
$_lang['upload.columns.state']            = '状態';
$_lang['upload.contextmenu.remove_entry'] = 'Remove entry';
$_lang['upload.clear_list.all']           = 'Clear list';
$_lang['upload.clear_list.notpermitted']  = 'Remove not permitted only';
$_lang['upload.msg.title.error']          = 'エラー';
$_lang['upload.upload.success']           = 'Upload successful';
